@@ -12,6 +12,8 @@ class TestStringMethods(unittest.TestCase):
         self.assertEqual(Map.Ruins_Of_Imladoon.original_author(), Developer.Fatline)
         self.assertEqual(Map.Ruins_Of_Imladoon.current_author(), Developer.Templar)
         self.assertFalse(Map.Vintage_Shores.is_map_available())
+        self.assertEqual(Map.Classic.get_name(Language.English), Map.Classic.get_english_name())
+        self.assertEqual(Map.from_index(0), Map.Classic)
 
     def test_roles(self):
         self.assertEqual(Role.Ares.get_current_author(), Role.Aewyn.get_current_author())
